@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * Copyright (c) 2015 Tim Theede <pez2001@voyagerproject.de>
- *               2015 Terry Cain <terrys-home.co.uk>
+ *               2015 Terri Cain <terri@dolphincorp.co.uk>
  */
 
 #ifndef __HID_RAZER_KBD_H
@@ -73,6 +73,7 @@
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_MINI 0x0258
 #define USB_DEVICE_ID_RAZER_BLADE_STEALTH_LATE_2020 0x0259
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_PRO_WIRED 0x025A
+#define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_PRO_WIRELESS 0x025C
 #define USB_DEVICE_ID_RAZER_ORNATA_V2 0x025D
 #define USB_DEVICE_ID_RAZER_CYNOSA_V2 0x025E
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_V2_ANALOG 0x0266
@@ -94,17 +95,23 @@
 #define USB_DEVICE_ID_RAZER_BLADE_17_2022 0x028B
 #define USB_DEVICE_ID_RAZER_BLADE_14_2022 0x028C
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4_PRO 0x028D
+#define USB_DEVICE_ID_RAZER_ORNATA_V3_ALT 0x028F
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_WIRELESS 0x0290
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_WIRED 0x0292
+#define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4_X 0x0293
 #define USB_DEVICE_ID_RAZER_ORNATA_V3_X 0x0294
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2 0x0295
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_TKL_WIRELESS 0x0296
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_TKL_WIRED 0x0298
+#define USB_DEVICE_ID_RAZER_BLADE_14_2023 0x029D
 #define USB_DEVICE_ID_RAZER_BLADE_15_2023 0x029E
 #define USB_DEVICE_ID_RAZER_BLADE_16_2023 0x029F
 #define USB_DEVICE_ID_RAZER_BLADE_18_2023 0x02A0
 #define USB_DEVICE_ID_RAZER_ORNATA_V3 0x02A1
 #define USB_DEVICE_ID_RAZER_ORNATA_V3_X_ALT 0x02A2
+#define USB_DEVICE_ID_RAZER_ORNATA_V3_TENKEYLESS 0x02A3
+#define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4_75PCT 0x02A5
+#define USB_DEVICE_ID_RAZER_BLADE_14_2024 0x02B6
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_TK 0x0A24
 
 /* Each keyboard report has 90 bytes*/
